@@ -66,10 +66,6 @@ module Labkit
         "#{LOG_KEY}.#{key}"
       end
 
-      def known_log_keys
-        @known_log_keys ||= (KNOWN_KEYS.map(&method(:log_key)) + RAW_KEYS).freeze
-      end
-
       private
 
       def contexts
