@@ -4,6 +4,8 @@ module Labkit
   # Logging provides functionality for logging, such as
   # sanitization
   module Logging
+    autoload :GRPC, "labkit/logging/grpc"
     autoload :Sanitizer, "labkit/logging/sanitizer"
+    autoload :JsonLogger, "labkit/logging/json_logger"
   end
 end
