@@ -5,7 +5,7 @@ module Labkit
     module Rails
       module ActiveRecord
         # For more information on the payloads: https://guides.rubyonrails.org/active_support_instrumentation.html
-        class SqlInstrumenter < AbstractInstrumenter
+        class SqlInstrumenter < Labkit::Tracing::AbstractInstrumenter
           OPERATION_NAME_PREFIX = "active_record:"
           DEFAULT_OPERATION_NAME = "sqlquery"
 
@@ -14,13 +14,19 @@ module Labkit
           end
 
           def tags(payload)
+            if Labkit::Tracing.sampled? && payload[:sql]
+              sql = Labkit::Logging::Sanitizer.sanitize_sql(payload[:sql])
+              fingerprint = Labkit::Logging::Sanitizer.sql_fingerprint(sql)
+            end
+
             {
               "component" => COMPONENT_TAG,
               "span.kind" => "client",
               "db.type" => "sql",
               "db.connection_id" => payload[:connection_id],
               "db.cached" => payload[:cached] || false,
-              "db.statement" => payload[:sql],
+              "db.statement" => sql,
+              "db.statement_fingerprint" => fingerprint,
             }
           end
         end
