@@ -5,7 +5,7 @@ module Labkit
     module Rails
       module ActiveSupport
         # For more information on the payloads: https://guides.rubyonrails.org/active_support_instrumentation.html
-        class CacheDeleteInstrumenter < AbstractInstrumenter
+        class CacheDeleteInstrumenter < Labkit::Tracing::AbstractInstrumenter
           def span_name(payload)
             "cache_delete"
           end
